@@ -57,7 +57,7 @@ class CaptainHook:
                 f"{self._baseurl}{endpoint}", data=data, timeout=self._timeout
             )
         except Exception:
-            logger.error("Impossibile contattare CaptainHook, stai usando la VPN?")
+            logger.error("Unable to contact Captainhook, are you using the VPN?")
             sys.exit(-1)
 
     def send_put_request(self, endpoint, data):
@@ -66,7 +66,7 @@ class CaptainHook:
                 f"{self._baseurl}{endpoint}", data=data, timeout=self._timeout
             )
         except Exception:
-            logger.error("Impossibile contattare CaptainHook, stai usando la VPN?")
+            logger.error("Unable to contact Captainhook, are you using the VPN?")
             sys.exit(-1)
 
     def send_get_request(self, endpoint):
@@ -75,7 +75,7 @@ class CaptainHook:
                 f"{self._baseurl}{endpoint}", timeout=(2, self._timeout)
             )
         except Exception:
-            logger.error("Impossibile contattare CaptainHook, stai usando la VPN?")
+            logger.error("Unable to contact Captainhook, are you using the VPN?")
             sys.exit(-1)
 
     def set_timeout(self, timeout):
