@@ -45,5 +45,5 @@ def qainit_shutdown(youtrack_id, config):
 
     else:
         logger.warning(
-            "Non sono riuscito a trovare un qa per questa issue, se il qa esiste, per favore spegnilo manualmente\nDevops are watching you! ( •͡˘ _•͡˘)"
+            "I could not find a QA env for this card, if the QA exists, please shut it down manually.\nDevops are watching you! ( •͡˘ _•͡˘)"
         )
